unit VaxQueueList;

interface


uses
    System.SysUtils,
    System.Classes,
    Generics.Collections,
    VaxQueueAgentList;

type TVaxQueueDetails = class

    private
        m_objQueueAgentList : TVaxAgentList;

    public
        m_sQueueName, m_sUserName, m_sCodecList : string;
        m_nModeId, m_nProcessType, m_nPriorityWeight : Integer;

    public

        function AddAgent(sAgentName : string) : boolean;
        procedure RemoveAgent(sAgentName : string);

        function GetAllAgentName(var objAgentNameList : TStringList): boolean;
        function GetAgentCount() : Integer;

    public

        constructor Create();


end;

type TVaxQueueList = class

    m_objQueueList : TObjectDictionary<string, TVaxQueueDetails>;

 private

        function GenKey(sValue : string) : string;
        procedure DeleteQueueAll();

        function FindQueue(sQueue : string) : TVaxQueueDetails;

      public

        constructor Create();
        Destructor Destroy();

        procedure ResetOBJ();

        function AddQueue(sQueueName : string) : boolean;
        procedure RemoveQueue(sQueueName : string);

        function AddQueueAgent(sQueueName : string; sAgentName : string) : boolean;
        procedure RemoveQueueAgent(sQueueName : string; sAgentName : string);

        procedure SetQueueProcessMode(sQueueName : string; nModeId : Integer; nModeType : Integer);
        function GetQueueAgentDetails(sQueueName : string; var nModeId : Integer; var nProcessType : Integer; var sListQueueAgent : TStringList) : boolean;

        function IsAgentExisted(sQueueName : string; sAgentName : string) : boolean;

        function GetQueueNameList(var sListQueueName: TStringList) : boolean;
        function GetQueueAgentAt(sQueueName : string; nIndex : Integer) : string;

      	function GetQueueAgentCount(sQueueName : string) : Integer;
end;

implementation

      //////////////////////////////////////////////////////////////////////////////////////////
      //////////////////////////// Queue Details //////////////////////////////////////////////

        function TVaxQueueDetails.AddAgent(sAgentName : string) : boolean;
        begin
              Result := m_objQueueAgentList.AddAgent(sAgentName);
        end;

        procedure TVaxQueueDetails.RemoveAgent(sAgentName : string);
        begin
              m_objQueueAgentList.RemoveAgent(sAgentName);
        end;

        function TVaxQueueDetails.GetAllAgentName(var objAgentNameList : TStringList): boolean;
        begin
               Result := m_objQueueAgentList.GetAllAgentName(objAgentNameList);
        end;

        function TVaxQueueDetails.GetAgentCount() : Integer;
        begin
              Result := m_objQueueAgentList.GetAgentCount();
        end;

        constructor TVaxQueueDetails.Create();
        begin
          m_objQueueAgentList := TVaxAgentList.Create();
        end;

      //////////////////////////////////////////////////////////////////////////////////////////
      /////////////////////////////// Queue List ///////////////////////////////////////////////

        constructor TVaxQueueList.Create();
        begin
            m_objQueueList := TObjectDictionary<string, TVaxQueueDetails>.Create([doOwnsValues], 256);
        end;

        Destructor TVaxQueueList.Destroy();
        begin
            DeleteQueueAll();
            m_objQueueList.Free;
        end;

        function TVaxQueueList.GenKey(sValue : string) : string;
        begin
            Result := AnsiLowerCase(sValue);
        end;

        procedure TVaxQueueList.DeleteQueueAll();
        begin
            m_objQueueList.Clear;
        end;

        function TVaxQueueList.FindQueue(sQueue : string) : TVaxQueueDetails;
        var
            objQueueDetails : TVaxQueueDetails;
            bResult : Boolean;
        begin
            objQueueDetails := Nil;

            bResult := m_objQueueList.TryGetValue(sQueue, objQueueDetails);
            if(bResult = False) then
                Exit(nil);

            Result := objQueueDetails;
        end;

        procedure TVaxQueueList.ResetOBJ();
        begin
            DeleteQueueAll();
        end;

        function TVaxQueueList.AddQueue(sQueueName : string) : boolean;
        var
            sKey : string;
            objQueueDetails : TVaxQueueDetails;

        begin
            objQueueDetails :=  FindQueue(sQueueName);

            if(objQueueDetails <> Nil) then
                Exit(False);

            objQueueDetails := TVaxQueueDetails.Create();

            objQueueDetails.m_sQueueName := sQueueName;
            m_objQueueList.Add(sQueueName, objQueueDetails);

            Exit(True);

        end;

        procedure TVaxQueueList.RemoveQueue(sQueueName : string);
         var
            sKey : string;
            objQueueDetails : TVaxQueueDetails;

        begin
            objQueueDetails :=  FindQueue(sQueueName);

            if(objQueueDetails <> Nil) then
             Exit();

             m_objQueueList.Remove(AnsiLowerCase(sQueueName));

        end;

        function TVaxQueueList.AddQueueAgent(sQueueName : string; sAgentName : string) : boolean;
        var
            objQueueDetails : TVaxQueueDetails;
            bResult : Boolean;

        begin

            objQueueDetails := Nil;

            bResult := m_objQueueList.TryGetValue(sQueueName, objQueueDetails);
            if(bResult = False) then
                Exit(False);

            Result := objQueueDetails.AddAgent(sAgentName);
        end;

        procedure TVaxQueueList.RemoveQueueAgent(sQueueName : string; sAgentName : string);
        var
            objQueueDetails : TVaxQueueDetails;
            bResult : Boolean;

        begin

            objQueueDetails := Nil;

            bResult := m_objQueueList.TryGetValue(sQueueName, objQueueDetails);
            if(bResult = False) then
            Exit();

            objQueueDetails.RemoveAgent(sQueueName);

        end;


        procedure TVaxQueueList.SetQueueProcessMode(sQueueName : string; nModeId : Integer; nModeType : Integer);
        var
            objQueueDetails : TVaxQueueDetails;
            bResult : Boolean;

        begin

            objQueueDetails := Nil;

            bResult := m_objQueueList.TryGetValue(sQueueName, objQueueDetails);
            if(bResult = False) then
            Exit();

            objQueueDetails.m_nModeId := nModeId;
            objQueueDetails.m_nProcessType := nModeType;

        end;

        function TVaxQueueList.GetQueueAgentDetails(sQueueName : string; var nModeId : Integer; var nProcessType : Integer; var sListQueueAgent : TStringList) : boolean;
        var
            objQueueDetails : TVaxQueueDetails;
            bResult : Boolean;

        begin

            objQueueDetails := Nil;

            bResult := m_objQueueList.TryGetValue(sQueueName, objQueueDetails);
            if(bResult = False) then
            Exit(False);

            nModeId := objQueueDetails.m_nModeId;
            nProcessType := objQueueDetails.m_nProcessType;

            Result := objQueueDetails.GetAllAgentName(sListQueueAgent);


        end;


        function TVaxQueueList.IsAgentExisted(sQueueName : string; sAgentName : string) : boolean;
        begin

        end;


        function TVaxQueueList.GetQueueNameList(var sListQueueName: TStringList) : boolean;
        var
          objQueueDetails : TVaxQueueDetails;
          sQueueName : string;
          nIndex : Integer;

        begin
                if(m_objQueueList.Count < 1) then
                  exit;

                for objQueueDetails in m_objQueueList.Values do
                begin
                   sListQueueName.Add(objQueueDetails.m_sQueueName)
                end;
        end;

        function TVaxQueueList.GetQueueAgentAt(sQueueName : string; nIndex : Integer) : string;
        begin

        end;


      	function TVaxQueueList.GetQueueAgentCount(sQueueName : string) : Integer;
        begin

        end;

end.
