#include "stdafx.h"
#include "VaxServerSIP.h"
#include "StatusLogDlg.h"
#include "ErrorLogDlg.h"
#include "StoreRegistry.h"
#include "StoreCOMM.h"
#include "StoreUser.h"
#include "StoreLine.h"
#include "StoreDirectProxy.h"
#include "StoreRoom.h"
#include "StoreRingGroup.h"
#include "StoreQueue.h"
#include "StoreCallPickUp.h"
#include "VaxSettingDefault.h"

#define HOLD_MUSIC_FILE  "..\\WaveFiles\\Hold.wav"
#define DIAL_TONE_MUSIC_FILE  "..\\WaveFiles\\DialTone.wav"
#define PARK_CALL_MUSIC_FILE  "..\\WaveFiles\\Hold.wav"

CVaxServerSIP::CVaxServerSIP()
{
	m_pVaxSettingDefault = new CVaxSettingDefault(this);
}

CVaxServerSIP::~CVaxServerSIP()
{
	delete m_pVaxSettingDefault;
}

/////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::Initialize(LPCTSTR sDomainRealm, LPCTSTR sSIPListenIP, int nSIPListenPort)
{
	CStoreCOMM objStoreCOMM;
	if(!objStoreCOMM.Initialize(sDomainRealm , sSIPListenIP, nSIPListenPort, sSIPListenIP, -1))
		return FALSE;

   if(!CVaxServerExCOM::Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sSIPListenIP, -1))
	   return FALSE;

   CVaxServerExCOM::SetListenPortRangeRTP(20000, 30000);
   return TRUE;
}

BOOL CVaxServerSIP::GetInitialize(CString& sSIPListenIP,  int& nSIPListenPort)
{
	CStoreCOMM objStoreCOMM;
	CString sDomainRealm, sRTPListenIP;

	int nRTPListenPort = -1;

	if(!objStoreCOMM.GetInitialize(sDomainRealm, sSIPListenIP, nSIPListenPort,sRTPListenIP, nRTPListenPort))
		return FALSE;

	return TRUE;
}

BOOL CVaxServerSIP::LoadMusicHold(LPCTSTR sFileName)
{
	CStoreCOMM objStoreCOMM;
    objStoreCOMM.SetMusicHold(sFileName);

	return CVaxServerExCOM::LoadMusicHold(sFileName);
}

CString CVaxServerSIP::GetMusicHold()
{
	CStoreCOMM objStoreCOMM;
    CString sFileName = "";

	if(!objStoreCOMM.GetMusicHold(sFileName))
	sFileName = HOLD_MUSIC_FILE;

	return sFileName;
}

BOOL CVaxServerSIP::LoadDialToneMusic(LPCTSTR sFileName)
{
	CStoreCOMM objStoreCOMM;
    objStoreCOMM.SetMusicDialTone(sFileName);

	return CVaxServerExCOM::LoadDialToneMusic(sFileName);
}

CString CVaxServerSIP::GetDialToneMusic()
{
	CStoreCOMM objStoreCOMM;
    CString sFileName = "";
    
	if(!objStoreCOMM.GetMusicDialTone(sFileName))
		sFileName = DIAL_TONE_MUSIC_FILE;

	return sFileName;
}

BOOL CVaxServerSIP::LoadMusicCallPark(LPCTSTR sFileName)
{
	CStoreCOMM objStoreCOMM;
	objStoreCOMM.SetMusicCallPark(sFileName);

	return CVaxServerExCOM::LoadMusicCallPark(sFileName);
}

CString CVaxServerSIP::GetMusicCallPark()
{
	CStoreCOMM objStoreCOMM;
    CString sFileName = "";

	if(!objStoreCOMM.GetMusicCallPark(sFileName))
		sFileName= PARK_CALL_MUSIC_FILE;

	return sFileName;
}

/////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddUser(LPCTSTR sLogin, LPCTSTR sPassword, LPCTSTR sCodecList, BOOL bBlocked, LPCTSTR sUserPrefix, LPCTSTR sDialPrefix, int nToPeerType, LPCTSTR sToPeerName, BOOL bStealthlisten)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreUser objStoreUser;
	objStoreUser.AddUser(sLogin, sPassword, sCodecList, bBlocked, bStealthlisten);

	CString sCallPrefixRoute, sDialPrefixRoute;

	sCallPrefixRoute = sUserPrefix;
	sDialPrefixRoute = sDialPrefix;

	if(!sCallPrefixRoute.IsEmpty() || !sDialPrefixRoute.IsEmpty())
	{
	    objStoreUser.AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
	   CVaxServerExCOM::AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
	}

	return CVaxServerExCOM::AddUser(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName, bStealthlisten);
}

void CVaxServerSIP::RemoveUser(LPCTSTR sLogin)
{
	if(!CVaxServerExCOM::IsInitialized())
	   return;

	CStoreUser objStoreUSer;
	objStoreUSer.RemoveUser(sLogin);

	CVaxServerExCOM::RemoveUser(sLogin);
	CVaxServerExCOM::RemoveUserRoute(sLogin);
}

BOOL CVaxServerSIP::GetUserDetails(LPCTSTR sUserName, CString& sPassword, CString& sCodecList, BOOL& bBlocked, CString& sUserPrefix, CString& sDialPrefix,  int& nToPeerType, CString& sToPeerName,  BOOL& bStealthlisten)
 {
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreUser objStoreUSer;
    objStoreUSer.GetUser(sUserName, sPassword, sCodecList, bBlocked, bStealthlisten);
    objStoreUSer.GetUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

    return TRUE;
 }

void CVaxServerSIP::GetUserAll(CStringList* pUserList)
{
	if(!CVaxServerExCOM::IsInitialized())
	  return;

    CStoreUser objStoreUSer;
	objStoreUSer.GetUserAll(pUserList);
}

/////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddLine(LPCTSTR sLineName, LPCTSTR sDisplayName, LPCTSTR sUserName, LPCTSTR sAuthUser, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxySIP, LPCTSTR sCodecList, BOOL bRegister, int nToPeerType, LPCTSTR sToPeerName, BOOL bRejected, LPCTSTR sRoomName, LPCTSTR sQueueName, LPCTSTR sRingGroupName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreLine objStoreLine;
	objStoreLine.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, "", sCodecList, bRegister);
	objStoreLine.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);

	CVaxServerExCOM::AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
	return CVaxServerExCOM::AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
}

void CVaxServerSIP::RemoveLine(LPCTSTR sLineName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreLine objStoreLine;
	objStoreLine.RemoveLine(sLineName);
	objStoreLine.RemoveLineRoute(sLineName);

	CVaxServerExCOM::RemoveLine(sLineName);
	CVaxServerExCOM::RemoveLineRoute(sLineName);
}

void CVaxServerSIP::GetLineAll(CStringList* pLineList)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreLine objStoreLine;
	objStoreLine.GetLineAll(pLineList);
}

BOOL CVaxServerSIP::GetLineDetails(LPCTSTR sLineName, CString& sDisplayName, CString& sUserName, CString& sAuthUser, CString& sAuthPwd, CString& sDomainRealm, CString& sProxySIP, CString& sCodecList, BOOL& bRegister, int& nToPeerType, CString& sToPeerName, BOOL& bRejected, CString& sRoomName, CString& sQueueName, CString& sRingGroupName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreLine objStoreLine;
	CString sOutBountProxySIP = "";

	objStoreLine.GetLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sOutBountProxySIP, sCodecList, bRegister);
	objStoreLine.GetLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);

	return TRUE;
}

/////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddDirectProxySIP(LPCTSTR sProxyName, LPCTSTR sAuthLogin, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxyIP, LONG lProxyPort, LPCTSTR sCodecList, int nToPeerType, LPCTSTR sToPeerName, BOOL bRejected, LPCTSTR sRoomName, LPCTSTR sQueueName, LPCTSTR sRingGroupName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreDirectProxy objStoreProxy;
	objStoreProxy.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList);
	objStoreProxy.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName,sQueueName, sRingGroupName);
		
	CVaxServerExCOM::AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
	return CVaxServerExCOM::AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
}

void CVaxServerSIP::RemoveDirectProxySIP(LPCTSTR sProxyName)
{
   if(!CVaxServerExCOM::IsInitialized())
	 return;

	CStoreDirectProxy objStoreProxy;
	objStoreProxy.RemoveDirectProxySIP(sProxyName);
	objStoreProxy.RemoveDirectProxyRoute(sProxyName);

	CVaxServerExCOM::RemoveDirectProxyRoute(sProxyName);
	CVaxServerExCOM::RemoveDirectProxySIP(sProxyName);
}

void CVaxServerSIP::GetDirectProxyAll(CStringList* pDirectProxyList)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreDirectProxy objStoreProxy;
	objStoreProxy.GetDirectProxyAll(pDirectProxyList);
}

BOOL CVaxServerSIP::GetDirectProxyDetails(LPCTSTR sProxyName, CString& sAuthLogin, CString& sAuthPwd, CString& sDomainRealm, CString& sProxyIP, LONG& lProxyPort, CString& sCodecList, int& nToPeerType, CString& sToPeerName, BOOL& bRejected, CString& sRoomName, CString& sQueueName, CString& sRingGroupName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreDirectProxy objStoreProxy;
    objStoreProxy.GetDirectyProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList);
	objStoreProxy.GetDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);

	return TRUE;
}

/////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddRoom(LPCTSTR sRoomName, LPCTSTR sRoomNo)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	RemoveRoom(sRoomName);
	
	if(!CVaxServerExCOM::AddRoom(sRoomName, sRoomNo))
		return FALSE;

	CStoreRoom objStoreRoom;
    objStoreRoom.AddRoom(sRoomName, sRoomNo);

	return TRUE;
}

void CVaxServerSIP::RemoveRoom(LPCTSTR sRoomName)
{
    if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreRoom objStoreRoom;
    objStoreRoom.RemoveRoom(sRoomName);

	CVaxServerExCOM::RemoveRoom(sRoomName);
}

BOOL CVaxServerSIP::GetRoomDetails(LPCTSTR sRoomName, CString& sRoomNo)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

   CStoreRoom objStoreRoom;
   objStoreRoom.GetRoom(sRoomName, sRoomNo);

    return TRUE;
}

BOOL CVaxServerSIP::GetRoomAll(CStringList* pRoomList)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreRoom objStoreRoom;
	objStoreRoom.GetRoomAll(pRoomList);

	return TRUE;
}
/////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddQueue(LPCTSTR sQueueName, LPCTSTR sQueueMusicFile, LPCTSTR sQueueDialToneFile)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreQueue objStoreQueue;
	objStoreQueue.AddQueue(sQueueName);

	if(!CVaxServerExCOM::AddQueue(sQueueName, sQueueMusicFile, sQueueDialToneFile))
		return FALSE;

	objStoreQueue.SetMusicFile(sQueueName, sQueueMusicFile);
	objStoreQueue.SetDialToneFile(sQueueName, sQueueDialToneFile);

	return TRUE;	
}

void CVaxServerSIP::RemoveQueue(LPCTSTR sQueueName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreQueue objStoreQueue;
	objStoreQueue.RemoveQueue(sQueueName);

	CVaxServerExCOM::RemoveQueue(sQueueName);
}

BOOL CVaxServerSIP::GetQueueNameAll(CStringList* sListQueueName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreQueue objStoreQueue;
	objStoreQueue.GetQueueNameAll(sListQueueName);

	return TRUE;
}

BOOL CVaxServerSIP::GetQueueDetails(LPCTSTR sQueueName, int& nProcessMode, int& nProcessType, CStringList* sListQueueAgent, CString& sQueueMusicFile, CString& sQueueDialToneFile)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreQueue objStoreQueue;
    objStoreQueue.GetQueueProcessMode(sQueueName, nProcessMode, nProcessType);
	objStoreQueue.GetQueueAgentNameAll(sQueueName, sListQueueAgent);

	objStoreQueue.GetMusicFile(sQueueName, sQueueMusicFile);
	objStoreQueue.GetDialToneFile(sQueueName, sQueueDialToneFile);

	return TRUE;
}

BOOL CVaxServerSIP::AddQueueAgent(LPCTSTR sQueueName, LPCTSTR sAgentName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreQueue objStoreQueue;
	objStoreQueue.AddQueueAgent(sQueueName, sAgentName);

	return TRUE;
}

void CVaxServerSIP::RemoveQueueAgent(LPCTSTR sQueueName, LPCTSTR sAgentName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreQueue objStoreQueue;
	objStoreQueue.RemoveQueueAgent(sQueueName, sAgentName);

	CVaxServerExCOM::RemoveQueueAgent(sQueueName, sAgentName);
}

void CVaxServerSIP::SetQueueAgentPriority(LPCTSTR sQueueName, LPCTSTR sAgentName, LONG lPriority)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreQueue objStoreQueue;
	objStoreQueue.SetQueueAgentPriority(sQueueName, sAgentName, lPriority);
	
	CVaxServerExCOM::SetQueueAgentPriority(sQueueName, sAgentName, lPriority);
}

void CVaxServerSIP::SetQueueProcessMode(LPCTSTR sQueueName, int nProcessMode, int nProcessType)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreQueue objStoreQueue;
	objStoreQueue.SetQueueProcessMode(sQueueName, nProcessMode, nProcessType);

	CVaxServerExCOM::SetQueueProcessMode(sQueueName, nProcessMode, nProcessType);
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddRingGroup(LPCTSTR sRingGroupName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	if(!CVaxServerExCOM::AddRingGroup(sRingGroupName))
		return FALSE;

	CStoreRingGroup objStoreRingGroup;
	objStoreRingGroup.AddRingGroup(sRingGroupName);

	return TRUE;
}

void CVaxServerSIP::RemoveRingGroup(LPCTSTR sRingGroupName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreRingGroup objStoreRingGroup;
	objStoreRingGroup.RemoveRingGroup(sRingGroupName);

    CVaxServerExCOM::RemoveRingGroup(sRingGroupName);
}

BOOL CVaxServerSIP::GetRingGroupNameAll(CStringList* sListRingGroupName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreRingGroup objStoreRingGroup;
	objStoreRingGroup.GetRingGroupList(sListRingGroupName);

	return TRUE;
}

BOOL CVaxServerSIP::GetRingGroupDetails(LPCTSTR sRingGroupName, int& nProcessMode, int& nProcessType, CStringList* sListAgentName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreRingGroup objStoreRingGroup;
	objStoreRingGroup.GetRingGroupProcessMode(sRingGroupName, nProcessMode, nProcessType);

	sListAgentName->RemoveAll();
	objStoreRingGroup.GetRingGroupAgentList(sRingGroupName, sListAgentName);

	return TRUE;
}

BOOL CVaxServerSIP::AddRingGroupAgent(LPCTSTR sRingGroupName, LPCTSTR sUserName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	if(!CVaxServerExCOM::AddRingGroupAgent(sRingGroupName, sUserName))
		return FALSE;

	CStoreRingGroup objStoreRingGroup;
	objStoreRingGroup.AddRingGroupAgent(sRingGroupName, sUserName);

	return TRUE;
}

void CVaxServerSIP::RemoveRingGroupAgent(LPCTSTR sRingGroupName, LPCTSTR sUserName)
{	
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreRingGroup objStoreRingGroup;
    objStoreRingGroup.RemoveRingGroupAgent(sRingGroupName, sUserName);
	CVaxServerExCOM::RemoveRingGroupAgent(sRingGroupName, sUserName);
}

void CVaxServerSIP::SetRingGroupProcessMode(LPCTSTR sRingGroupName, int nProcessMode, int nProcessType)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreRingGroup objStoreRingGroup;
	objStoreRingGroup.SetRingGroupProcessMode(sRingGroupName, nProcessMode, nProcessType);

	CVaxServerExCOM::SetRingGroupProcessMode(sRingGroupName, nProcessMode, nProcessType);
}

BOOL CVaxServerSIP::SetRingGroupAgentPriority(LPCTSTR sRingGroupName, LPCTSTR sAgentName, int nPriority)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	if(!CVaxServerExCOM::SetRingGroupAgentPriority(sRingGroupName, sAgentName, nPriority))
		return FALSE;

	CStoreRingGroup objStoreRingGroup;
	objStoreRingGroup.SetRingGroupAgentPriority(sRingGroupName, sAgentName, nPriority);

	return TRUE;
}

/////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddCallPickUpGroup(LPCTSTR sPickupGroupName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	if(!CVaxServerExCOM::AddCallPickUpGroup(sPickupGroupName))
		return FALSE;

	CStoreCallPickUp objStoreCallPickUp;
	objStoreCallPickUp.AddCallPickUpGroup(sPickupGroupName);

	return TRUE;
}

void CVaxServerSIP::RemoveCallPickUpGroup(LPCTSTR sPickupGroupName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreCallPickUp objStoreCallPickUp;
	objStoreCallPickUp.RemoveCallPickUpGroup(sPickupGroupName);

	CVaxServerExCOM::RemoveCallPickUpGroup(sPickupGroupName);
}

BOOL CVaxServerSIP::GetPickUpGroupNameAll(CStringList* sListPickUpName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreCallPickUp objStoreCallPickUp;
	objStoreCallPickUp.GetCallPickUpGroupNameAll(sListPickUpName);

	return TRUE;
}

BOOL CVaxServerSIP::GetPickUpMemberName(LPCTSTR sPickUpGroupName, CStringList* sListMemberName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreCallPickUp objStoreCallPickUp;
	objStoreCallPickUp.GetPickUpMemberNameAll(sPickUpGroupName, sListMemberName);

	return TRUE;
}

BOOL CVaxServerSIP::AddCallPickUpGroupMember(LPCTSTR sPickupGroupName, LPCTSTR sMemberName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	if(!CVaxServerExCOM::AddCallPickUpGroupMember(sPickupGroupName, sMemberName))
		return FALSE;

	CStoreCallPickUp objStoreCallPickUp;
	objStoreCallPickUp.AddCallPickUpGroupMember(sPickupGroupName, sMemberName);

	return TRUE;
}

void CVaxServerSIP::RemoveCallPickUpGroupMember(LPCTSTR sPickupGroupName, LPCTSTR sMemberName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreCallPickUp objStoreCallPickUp;
	objStoreCallPickUp.RemoveCallPickUpGroupMemeber(sPickupGroupName, sMemberName);

	CVaxServerExCOM::RemoveCallPickUpGroupMember(sPickupGroupName, sMemberName);
}

////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////

void CVaxServerSIP::LoadUser()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStringList objListUsers;

	CStoreUser objStoreUser;
	objStoreUser.GetUserAll(&objListUsers);

	if(objListUsers.IsEmpty())
		return;

	CString sUserName, sPassword, sCodecList, sUserPrefix, sDialPrefix, sToPeerName;
    
	BOOL bBlocked = FALSE;
	BOOL bStealthListen= FALSE;

    int nToPeerType = -1;
		
	while(!objListUsers.IsEmpty())
	{
		sUserName = objListUsers.RemoveHead();
		
		objStoreUser.GetUser(sUserName, sPassword, sCodecList, bBlocked, bStealthListen);
		objStoreUser.GetUserRoute(sUserName, sUserPrefix, sDialPrefix,  nToPeerType, sToPeerName);

		if(sUserPrefix.GetLength() != 0 || sDialPrefix.GetLength() != 0)
		{
			CVaxServerExCOM::AddUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
		}

		CVaxServerExCOM::AddUser(sUserName, sPassword, sCodecList);
	}
}

void CVaxServerSIP::LoadLine()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStringList objListLine;

	CStoreLine objStoreLine;
	objStoreLine.GetLineAll(&objListLine);

	if(objListLine.IsEmpty())
		return;

	CString sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sCodecList, sProxySIP, sOutboundProxySIP, sToPeerName, sRoomName, sQueueName, sRingGroupName;

	BOOL bRejectCall = FALSE;
	BOOL bRegister = FALSE;
	BOOL bRejected = FALSE;

	int nToPeerType = -1;
		
	while(!objListLine.IsEmpty())
	{
		sLineName = objListLine.RemoveHead();

		objStoreLine.GetLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sOutboundProxySIP, sCodecList, bRegister);
        objStoreLine.GetLineRoute(sLineName, nToPeerType, sToPeerName, bRejectCall, sRoomName, sQueueName, sRingGroupName);

		CVaxServerExCOM::AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm,  sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
		CVaxServerExCOM::AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejectCall, sRoomName, sQueueName, sRingGroupName);
	}
}

void CVaxServerSIP::LoadDirectProxy()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

   CStringList objListDirectProxy;

   CStoreDirectProxy objStoreProxy;
   objStoreProxy.GetDirectProxyAll(&objListDirectProxy);

   if(objListDirectProxy.IsEmpty())
	   return;

   CString sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, sCodecList, sToPeerName, sRoomName, sQueueName, sRingGroupName;

	LONG lProxyPort = -1;
	int nToPeerType = -1;

	BOOL bRejected = FALSE;
		
	while(!objListDirectProxy.IsEmpty())
	{
		sProxyName = objListDirectProxy.RemoveHead();

		objStoreProxy.GetDirectyProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList);
		objStoreProxy.GetDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);

		CVaxServerExCOM::AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd,  sDomainRealm, sProxyIP, lProxyPort, sCodecList, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
		CVaxServerExCOM::AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
   }
}

void CVaxServerSIP::LoadRoom()
{
	if(!CVaxServerExCOM::IsInitialized())
       return;
	
	CStringList objListConfRoom;

	CStoreRoom objStoreRoom;
	objStoreRoom.GetRoomAll(&objListConfRoom);

	if(objListConfRoom.IsEmpty())
		return;

	CString sRoomName, sRoomNo;
	
	while(!objListConfRoom.IsEmpty())
	{
		sRoomName = objListConfRoom.RemoveHead();

		objStoreRoom.GetRoom(sRoomName, sRoomNo);
		CVaxServerExCOM::AddRoom(sRoomName, sRoomNo);
	}
}

void CVaxServerSIP::LoadQueue()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStringList objListQueue;

	CStoreQueue objStoreQueue;
	objStoreQueue.GetQueueNameAll(&objListQueue);

	if(objListQueue.IsEmpty())
		return;

	CString sQueueName, sQueueMusicFile , sQueueDialToneMusic ;
	int nProcessMode = -1, nProcessType = -1;

	CStringList objListAgentName;

	while(!objListQueue.IsEmpty())
	{
	   sQueueName = objListQueue.RemoveHead();
	   
	   objStoreQueue.GetMusicFile( sQueueName, sQueueMusicFile);
	   objStoreQueue.GetDialToneFile(sQueueName, sQueueDialToneMusic);

	   objStoreQueue.GetQueueAgentNameAll(sQueueName, &objListAgentName);
	   objStoreQueue.GetQueueProcessMode(sQueueName, nProcessMode, nProcessType);

	   CVaxServerExCOM::AddQueue(sQueueName, sQueueMusicFile, sQueueDialToneMusic);
	   CVaxServerExCOM::SetQueueProcessMode(sQueueName, nProcessMode, nProcessType);

       AddQueueAgents(sQueueName, objListAgentName);
   }
}

void CVaxServerSIP::AddQueueAgents(LPCTSTR sQueueName, CStringList& objListQueueAgent)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreQueue objStoreQueue;
   
	 LONG lPriority = -1;
	 CString sAgentName = "";

	 POSITION posList = NULL;

   for(int nIndex = 0 ; nIndex < objListQueueAgent.GetCount(); nIndex++)
   {
	   posList = objListQueueAgent.FindIndex(nIndex);
	   sAgentName = objListQueueAgent.GetAt(posList);

	   if(posList == NULL)
		   continue;

	   objStoreQueue.GetQueueAgentPriority(sQueueName, sAgentName, lPriority);

	   CVaxServerExCOM::AddQueueAgent(sQueueName, sAgentName);
	   CVaxServerExCOM::SetQueueAgentPriority(sQueueName, sAgentName, lPriority);
   }
}

void CVaxServerSIP::LoadRingGroup()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStringList objListRingGroup;

	CStoreRingGroup objStroeRingGroup;
	objStroeRingGroup.GetRingGroupList(&objListRingGroup);

	if(objListRingGroup.IsEmpty())
		return;

	CString sRingGroupName;
    int nProcessMode = -1, nProcessType = -1;
	CStringList objListRingGroupAgent;

	while(!objListRingGroup.IsEmpty())
	{
		sRingGroupName = objListRingGroup.RemoveHead();
	   
	   objStroeRingGroup.GetRingGroupAgentList(sRingGroupName, &objListRingGroupAgent);
	   objStroeRingGroup.GetRingGroupProcessMode(sRingGroupName, nProcessMode, nProcessType);

	   CVaxServerExCOM::AddRingGroup(sRingGroupName);
	   CVaxServerExCOM::SetRingGroupProcessMode(sRingGroupName, nProcessMode, nProcessType);
	   AddRingGroupAgents(sRingGroupName, objListRingGroupAgent);
	}
}

void CVaxServerSIP::AddRingGroupAgents(LPCTSTR sRingGroupName,  CStringList& objListRingGroupAgents)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreRingGroup objStoreRingGroup;

	 int nPriority = -1;
	 CString sAgentName;
      
	 POSITION posList = NULL;

	 for(int nIndex = 0; nIndex < objListRingGroupAgents.GetCount(); nIndex++)
	 {
		posList = objListRingGroupAgents.FindIndex(nIndex);
		if(posList == NULL) continue;

		sAgentName = objListRingGroupAgents.GetAt(posList);
		objStoreRingGroup.GetRingGroupAgentPriority(sRingGroupName, sAgentName, nPriority);

		CVaxServerExCOM::AddRingGroupAgent(sRingGroupName, sAgentName);
		CVaxServerExCOM::SetRingGroupAgentPriority(sRingGroupName, sAgentName, nPriority);
	 }
}

void CVaxServerSIP::LoadCallPickupGroup()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStringList objListCallPickUp;

	CStoreCallPickUp objStoreCallPickUp;
	objStoreCallPickUp.GetCallPickUpGroupNameAll(&objListCallPickUp);

	if(objListCallPickUp.IsEmpty())
		return;

	CStringList objListCallPickUpAgent;
	CString sGroupName;
	
	while(!objListCallPickUp.IsEmpty())
	{
		sGroupName = objListCallPickUp.RemoveHead();

		objStoreCallPickUp.GetPickUpMemberNameAll(sGroupName, &objListCallPickUpAgent);
	   
		CVaxServerExCOM::AddCallPickUpGroup(sGroupName);
		AddPickupGroupAgents(sGroupName, objListCallPickUpAgent);
   }
}

void CVaxServerSIP::AddPickupGroupAgents(LPCTSTR sGroupName, CStringList& objListCallPickUpAgents)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreCallPickUp objStoreCallPickUp;

	CString sPickUpGroupName, sMemberName;
	POSITION posList = NULL;

	for(int nIndex = 0; nIndex < objListCallPickUpAgents.GetCount(); nIndex++)
	{
		posList = objListCallPickUpAgents.FindIndex(nIndex);
		if(posList == NULL) continue;

	   CVaxServerExCOM::AddCallPickUpGroupMember(sPickUpGroupName, sMemberName);
   }
}

/////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////

void CVaxServerSIP::OnInitialize()
{
	if(!m_pVaxSettingDefault->LoadUserDefault())
	{
		LoadUser();
	}
	
	if(!m_pVaxSettingDefault->LoadLineDefault())
	{
		LoadLine();
	}
	
	if(!m_pVaxSettingDefault->LoadRoomDefault())
	{
		LoadRoom();
	}
                        
	LoadDirectProxy();

	if(!m_pVaxSettingDefault->LoadQueueDefault())
	{
		LoadQueue();
	}

	if(!m_pVaxSettingDefault->LoadRingGroupDefault())
	{
		LoadRingGroup();
	}

	if(!m_pVaxSettingDefault->LoadCallPickUpGroupDefault())
	{
		LoadCallPickupGroup();
	}
}

void CVaxServerSIP::OnStatusLog(LPCTSTR sStatus)
{
	m_pStatusLogDlg->OnStatusLog(sStatus);
}

void CVaxServerSIP::OnErrorLog(LPCTSTR sError)
{
	m_pErrorLogDlg->OnErrorLog(sError);
}