#include "StdAfx.h"
#include "Define.h"
#include "VaxServerExCOM.h"
#include "ConfRoom.h"
#include "VaxCallSession.h"
#include "VaxUser.h"
#include "VaxChat.h"
#include "VaxLine.h"
#include "VaxDirectProxy.h"
#include "VaxCallSessionRoute.h"

CVaxServerExCOM::CVaxServerExCOM()
{
	m_lDialToneId = -1;
	m_nRegisterUserCount = 0;
			
	m_pConfRoom = new CConfRoom(this);
	m_pChat = new CVaxChat(this);
	m_pRouteCallSIP = new CVaxCallSessionRoute(this);

	m_bInitilized= FALSE;
}

CVaxServerExCOM::~CVaxServerExCOM()
{
	UnInitialize();

	delete m_pConfRoom;
	delete m_pChat;
	delete m_pRouteCallSIP;

	CVaxServerCOM::UnLoadObjectCOM();
}

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::SetLicenseKey(LPCTSTR sLicenseKey)
{
	m_sLicenseKey = sLicenseKey;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::Initialize(LPCTSTR sDomainRealm, LPCTSTR sSIPListenIP, UINT nSIPListenPort, LPCTSTR sRTPListenIP, UINT nRTPListenPort)
{
	CVaxServerCOM::SetLicenseKey(m_sLicenseKey);

	if(!CVaxServerCOM::Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sRTPListenIP, nRTPListenPort))
		return FALSE;

	m_bInitilized = TRUE;

	OnInitialize();
	return TRUE;
}

void CVaxServerExCOM::UnInitialize()
{
	m_bInitilized = FALSE;
	m_nRegisterUserCount = 0;

	m_pConfRoom->DeleteRoomAll();
	m_pRouteCallSIP->ResetOBJ();

	DeleteCallSessionDataAll();
	DeleteUserDataAll();
	DeleteLineDataAll();
	
	CVaxServerCOM::UnInitialize();
}

BOOL CVaxServerExCOM::IsInitialized()
{

	return m_bInitilized;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddUser(LPCTSTR sUserName, LPCTSTR sPassword, LPCTSTR sCodecList, BOOL bBlocked, LPCTSTR sUserPrefix, LPCTSTR sDialPrefix, int nToPeerType, LPCTSTR sToPeerName)
{
	if(!CVaxServerCOM::AddUser(sUserName, sPassword, sCodecList))	
	{
		return FALSE;
	}

	CVaxUser* pUser = new CVaxUser(this);
	CVaxServerCOM::SetUserData(sUserName, (HANDLE) pUser);

	pUser->SetData(sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
	return TRUE;
}

void CVaxServerExCOM::RemoveUser(LPCTSTR sUserName)
{
	if(!IsUserExist(sUserName))
		return;

	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserName);
	delete pUser;
	
	CVaxServerCOM::RemoveUser(sUserName);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddLine(LPCTSTR sLineName, LPCTSTR sDisplayName, LPCTSTR sUserName, LPCTSTR sAuthUser, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxySIP, LPCTSTR sCodecList, BOOL bRegister, int nToPeerType, LPCTSTR sToPeerName, BOOL bBlock, LPCTSTR sRoomName)
{
	BOOL bResult = CVaxServerCOM::AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, "", sCodecList);
	if(!bResult)
	{
		return FALSE;
	}

	CVaxLine* pLine = new CVaxLine(this);
	
	CVaxServerCOM::SetLineData(sLineName, (HANDLE) pLine);
	pLine->SetData(sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlock, sRoomName);

	if(bRegister)
		CVaxServerCOM::RegisterLine(sLineName, 1800);

	return TRUE;
}

void CVaxServerExCOM::RemoveLine(LPCTSTR sLineName)
{
	if(!IsLineExist(sLineName))
		return;

	CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
	delete pLine;

	CVaxServerCOM::RemoveLine(sLineName);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddDirectProxySIP(LPCTSTR sProxyName, LPCTSTR sAuthLogin, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxyIP, LONG lProxyPort, LPCTSTR sCodecList, int nToPeerType, LPCTSTR sToPeerName, BOOL bBlocked, LPCTSTR sRoomName)
{
	BOOL bResult = CVaxServerCOM::AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList);
	if(!bResult)
	{
		return FALSE;
	}

	CVaxDirectProxy* pDirectProxy = new CVaxDirectProxy(this);
	CVaxServerCOM::SetDirectProxyData(sProxyName, (HANDLE) pDirectProxy);

	pDirectProxy->SetData(sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList, nToPeerType, sToPeerName, bBlocked, sRoomName);
	
	return TRUE;
}
void CVaxServerExCOM::RemoveDirectProxySIP(LPCTSTR sProxyName)
{
	if(!IsDirectProxyExist(sProxyName))
		return;

	CVaxDirectProxy* pDirectProxy = (CVaxDirectProxy*) CVaxServerCOM::GetDirectProxyData(sProxyName);
	delete pDirectProxy;

	CVaxServerCOM::RemoveDirectProxySIP(sProxyName);
}


//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

LONG CVaxServerExCOM::GetVaxErrorCode()
{
	return CVaxServerCOM::GetVaxErrorCode();
}

BOOL CVaxServerExCOM::DialToneToCallSession(BOOL bEnable, LONG nSessionId)
{
	if(m_lDialToneId == -1)
		return TRUE;
	
	return CVaxServerCOM::DialToneToCallSession(bEnable, nSessionId, m_lDialToneId);
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddRoom(LPCTSTR sRoomName, LPCTSTR sRoomNo)
{
	return m_pConfRoom->AddRoom(sRoomName, sRoomNo);
}

void CVaxServerExCOM::RemoveRoom(LPCTSTR sRoomName)
{
	m_pConfRoom->RemoveRoom(sRoomName);
}


//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddUserRoute(LPCTSTR sUserName, LPCTSTR sUserPrefix, LPCTSTR sDialPrefix, int nToPeerType, LPCTSTR sToPeerName)
{
	return m_pRouteCallSIP->AddUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
}

void CVaxServerExCOM::RemoveUserRoute(LPCTSTR sUserName)
{
	m_pRouteCallSIP->RemoveUserRoute(sUserName);
}

BOOL CVaxServerExCOM::AddLineRoute(LPCTSTR sLineName, int nToPeerType, LPCTSTR sToPeerName, BOOL bRejected, LPCTSTR sRoomName)
{
	return m_pRouteCallSIP->AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);
}

void CVaxServerExCOM::RemoveLineRoute(LPCTSTR sLineName)
{
	m_pRouteCallSIP->RemoveLineRoute(sLineName);
}

BOOL CVaxServerExCOM::AddDirectProxyRoute(LPCTSTR sProxyName, int nToPeerType, LPCTSTR sToPeerName, BOOL bRejected, LPCTSTR sRoomName)
{
	return m_pRouteCallSIP->AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName);
}

void CVaxServerExCOM::RemoveDirectProxyRoute(LPCTSTR sProxyName)
{
	m_pRouteCallSIP->RemoveDirectProxyRoute(sProxyName);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::LoadMusicDialTone(LPCTSTR sFileName)
{
	UnLoadMusicDialTone();

	m_lDialToneId = CVaxServerCOM::LoadWaveFile(sFileName);
	return (m_lDialToneId != -1);
}

void CVaxServerExCOM::UnLoadMusicDialTone()
{
	if(m_lDialToneId != -1)
	{
		CVaxServerCOM::UnLoadWaveFile(m_lDialToneId);
		m_lDialToneId = -1;
	}
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

LONG CVaxServerExCOM::GetCallCount()
{
	return CVaxServerCOM::GetCallCount();
}

UINT CVaxServerExCOM::GetRegisteredUserCount()
{
	return m_nRegisterUserCount;
}

BOOL CVaxServerExCOM::IsRoomNoExist(LPCTSTR sRoomNo)
{
	return m_pConfRoom->IsRoomNoExists(sRoomNo);
}

BOOL CVaxServerExCOM::IsUserExist(LPCTSTR sUserName)
{
	if (!CVaxServerCOM::TrvsUserStart())
		return FALSE;

	while (TRUE)
	{
		CString sUser = CVaxServerCOM::TrvsUserNext();
		if (sUser.IsEmpty()) break;

		if (sUser == sUserName)
			return TRUE;
	}

	return FALSE;
}

BOOL CVaxServerExCOM::IsLineExist(LPCTSTR sLineName)
{
	if (!CVaxServerCOM::TrvsLineStart())
		return FALSE;

	while (TRUE)
	{
		CString sLine = CVaxServerCOM::TrvsLineNext();
		if(sLine.IsEmpty()) break;

		if(sLine == sLineName)
			return TRUE;
	}

	return FALSE;
}

BOOL CVaxServerExCOM::IsDirectProxyExist(LPCTSTR sProxyName)
{
	if (!CVaxServerCOM::TrvsDirectProxyStart())
		return FALSE;

	while (TRUE)
	{
		CString sProxy = CVaxServerCOM::TrvsDirectProxyNext();
		if(sProxy.IsEmpty()) break;

		if(sProxy == sProxyName)
			return TRUE;
	}

	return FALSE;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::DeleteCallSessionDataAll()
{
	if(!CVaxServerCOM::TrvsCallSessionStart())
		return;

	for(int nCount = 0; nCount < CVaxServerCOM::GetCallSessionCount(); nCount++)
	{
		LONG nSessionId = CVaxServerCOM::TrvsCallSessionNext();
		if(nSessionId == -1) continue;

		CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nSessionId);
		if(pCallSession == NULL) continue;

		delete pCallSession;
	}
}

void CVaxServerExCOM::DeleteUserDataAll()
{
	if(!CVaxServerCOM::TrvsUserStart())
		return;

	for(int nCount = 0; nCount < CVaxServerCOM::GetUserCount(); nCount++)
	{
		CString sUserName = CVaxServerCOM::TrvsUserNext();
		if(sUserName.IsEmpty()) continue;

		CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserName);
		if(pUser == NULL) continue;

		delete pUser;
	}
}

void CVaxServerExCOM::DeleteLineDataAll()
{
	if(!CVaxServerCOM::TrvsLineStart())
		return;

	for(int nCount = 0; nCount < CVaxServerCOM::GetLineCount(); nCount++)
	{
		CString sLineName = CVaxServerCOM::TrvsLineNext();
		if(sLineName.IsEmpty()) continue;

		CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
		if(pLine == NULL) continue;

		delete pLine;
	}
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnRegisterUser(LPCTSTR sUserLogin, LPCTSTR sDomain, LPCTSTR sUserAgent, LPCTSTR sFromIP, LONG nFromPort, LONG nRegId)
{
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserLogin);

	if(pUser == NULL)
	{
		CVaxServerCOM::RejectRegister(nRegId, 404, "Not Found");
		return;
	}

	pUser->OnRegisterUser(sUserLogin, sDomain, sUserAgent, sFromIP, nFromPort, nRegId);
}

void CVaxServerExCOM::OnRegisterUserSuccess(LPCTSTR sUserLogin, LPCTSTR sFromIP, LONG nFromPort, LONG nRegId)
{
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserLogin);

	if(!pUser->IsRegistered())
		m_nRegisterUserCount++;

	pUser->OnRegisterUserSuccess(sUserLogin, sFromIP, nFromPort, nRegId);
}

void CVaxServerExCOM::OnRegisterUserFailed(LPCTSTR sUserLogin, LPCTSTR sFromIP, LONG nFromPort, LONG nRegId)
{
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserLogin);
	pUser->OnRegisterUserFailed(sUserLogin, sFromIP, nFromPort, nRegId);
}

void CVaxServerExCOM::OnUnRegisterUser(LPCTSTR sUserLogin)
{
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserLogin);
	
	if(pUser->IsRegistered())
		m_nRegisterUserCount--;
	
	pUser->OnUnRegisterUser(sUserLogin);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnIncomingCall(LONG nSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, LONG nFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sUserAgent, LPCTSTR sFromIP, LONG nFromPort)
{
	CString sToPeerName; CString sDialToNo; CString sRoomName;
	int nToPeerType = -1;  BOOL bRejected = FALSE;
	
	////////////////////////////////////////////////////////////////
	
	if(nFromPeerType == VAX_PEER_TYPE_USER)
	{
		if(m_pConfRoom->IsRoomNoExists(sDialNo))
			sRoomName = m_pConfRoom->GetRoomName(sDialNo);
		else
			m_pRouteCallSIP->OnCallFromUser(sFromPeerName, sDialNo, sDialToNo, nToPeerType, sToPeerName);
	}
	else if(nFromPeerType == VAX_PEER_TYPE_LINE)
	{
		m_pRouteCallSIP->OnCallFromLine(sFromPeerName, nToPeerType, sToPeerName, bRejected, sRoomName);
		sDialToNo = sToPeerName;
	}
	else if(nFromPeerType == VAX_PEER_TYPE_DIRECT_PROXY)
	{
		m_pRouteCallSIP->OnCallFromDirectProxySIP(sFromPeerName, nToPeerType, sToPeerName, bRejected, sRoomName);
		sDialToNo = sToPeerName;
	}

	//////////////////////////////////////////////////////////////////////
	
	if(bRejected)
	{
		CVaxServerCOM::RejectCallSession(nSessionId, 404, "Not Found");
		return;
	}

	DialToneToCallSession(TRUE, nSessionId);
	
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nSessionId);
	pCallSession->OnIncomingCall(nSessionId, sCallerName, sCallerId, sDialNo, sRoomName, nFromPeerType, sFromPeerName, nToPeerType, sToPeerName, sUserAgent, sFromIP, nFromPort);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionCreated(LONG nSessionId, LONG nReasonCode)
{
	CVaxCallSession* pCallSession = new CVaxCallSession(this);
	CVaxServerCOM::SetCallSessionData(nSessionId, (HANDLE) pCallSession);
}

void CVaxServerExCOM::OnCallSessionClosed(LONG nSessionId, LONG nChannelId, LONG nReasonCode)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nSessionId);
	delete pCallSession;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionConnecting(LONG nSessionId, LONG nChannelId, LONG nStatusCode, LPCTSTR sReasonPhrase)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nSessionId);
	pCallSession->OnCallSessionConnecting(nSessionId, nChannelId, nStatusCode, sReasonPhrase);
}

void CVaxServerExCOM::OnCallSessionFailed(LONG nSessionId, LONG nChannelId, LONG nStatusCode, LPCTSTR sReasonPhrase)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nSessionId);
	pCallSession->OnCallSessionFailed(nSessionId, nChannelId, nStatusCode, sReasonPhrase);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionOnHold(LONG nSessionId, LONG nChanneld)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nSessionId);
	pCallSession->OnCallSessionOnHold(nSessionId, nChanneld);
}

void CVaxServerExCOM::OnCallSessionOffHold(LONG nSessionId, LONG nChanneld)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nSessionId);
	pCallSession->OnCallSessionOffHold(nSessionId, nChanneld);
}

///////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionTransferBlind(LONG nTransfererSessionId, LONG nTransfererChannelId, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nTransfererSessionId);
	pCallSession->OnCallSessionTransferBlind(nTransfererSessionId, nTransfererChannelId, sTransferer, sTransferee, sTransferTo);
}

void CVaxServerExCOM::OnCallSessionTransferConsult(LONG nTransfererSessionId, LONG nTransfereeSessionId, LONG nTransferToSessionId, LONG nTransfererChannelId, LONG nTransfereeChannelId, LONG nTransferToChannelId, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nTransfererSessionId);
	pCallSession->OnCallSessionTransferConsult(nTransfererSessionId, nTransfererChannelId, nTransferToSessionId, nTransferToChannelId, sTransferer, sTransferee, sTransferTo);
}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionRecordedPCM(LONG nSessionId, LONG nChannelId, LONGLONG nDataPCM, LONG nSizePCM, LONG nTypePCM)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nSessionId);
	pCallSession->OnCallSessionRecordedPCM(nSessionId, nChannelId, (char*) nDataPCM, nSizePCM); 
}

void CVaxServerExCOM::OnConferenceRoomRecordedPCM(LPCTSTR sRoomName, LONGLONG nDataPCM, LONG nSizePCM, LONG nTypePCM)
{
	
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////
	
void CVaxServerExCOM::OnChatMessageText(LONG lChatMsgId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LPCTSTR sMsgText, LONG nFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG nFromPort)
{
	m_pChat->OnChatMessageText(lChatMsgId, sMsgFrom, sMsgTo, sMsgText, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
}

void CVaxServerExCOM::OnChatMessageTyping(LONG lChatMsgId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, BOOL IsTypingStart, LONG nFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG nFromPort)
{
	m_pChat->OnChatMessageTyping(lChatMsgId, sMsgFrom, sMsgTo, IsTypingStart, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
}

void CVaxServerExCOM::OnChatStatusSubscribe(LONG lSubscrbId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LONG nFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG nFromPort)
{
	m_pChat->OnChatStatusSubscribe(lSubscrbId, sMsgFrom, sMsgTo, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
}

void CVaxServerExCOM::OnChatMessageSuccess(LONG lChatMsgId)
{
	m_pChat->OnChatMessageSuccess(lChatMsgId);
}

void CVaxServerExCOM::OnChatMessageFailed(LONG lChatMsgId, LONG lStatusId, LPCTSTR sReasonPhrase)
{
	m_pChat->OnChatMessageFailed(lChatMsgId, lStatusId, sReasonPhrase);
}

void CVaxServerExCOM::OnChatMessageTimeout(LONG lChatMsgId)
{
	m_pChat->OnChatMessageTimeout(lChatMsgId);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnLineRegisterTrying(LPCTSTR sLineName)
{
	CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
	if(pLine == NULL) return;

	pLine->OnLineRegisterTrying(sLineName);
}

void CVaxServerExCOM::OnLineRegisterFailed(LPCTSTR sLineName, LONG nStatusCode, LPCTSTR sReasonPhrase)
{
	CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
	if(pLine == NULL) return;

	pLine->OnLineRegisterFailed(sLineName, nStatusCode, sReasonPhrase);
}

void CVaxServerExCOM::OnLineRegisterSuccess(LPCTSTR sLineName)
{
	CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
	if(pLine == NULL) return;

	pLine->OnLineRegisterSuccess(sLineName);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnDetectedDigitDTMF(LONG nSessionId, LONG nChanneld, LPCTSTR sDigitDTMF)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(nSessionId);
	pCallSession->OnDetectedDigitDTMF(nSessionId, nChanneld, sDigitDTMF);
}

/////////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnBusyLampSubscribe(LONG nSubScrbId, LPCTSTR sUserName, LPCTSTR sToUserName, LPCTSTR sFromIP, LONG nFromPort)
{
	CVaxServerCOM::BusyLampSubscribeAccept(nSubScrbId, TRUE, 30);
}

void CVaxServerExCOM::OnBusyLampUnSubscribe(LONG nSubScrbId, LPCTSTR sUserName, LPCTSTR sToUserName, LPCTSTR sFromIP, LONG nFromPort)
{

}

void CVaxServerExCOM::OnBusyLampSubscribeSuccess(LONG nSubScrbId, LPCTSTR sUserName)
{

}

void CVaxServerExCOM::OnBusyLampSubscribeFailed(LONG nSubScrbId, LPCTSTR sUserName)
{

}

void CVaxServerExCOM::OnBusyLampSendStatus(LPCTSTR sFromUserName, LPCTSTR sToUserName, LONG nStateId)
{
	CVaxServerCOM::BusyLampSendStatus(sFromUserName, sToUserName, nStateId);
}


//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::GenStatusLog(LPCTSTR sStatus)
{
	OnStatusLog(sStatus);
}

void CVaxServerExCOM::OnVaxErrorLog(LPCTSTR sFuncName, LONG nErrorCode, LPCTSTR sErrorMsg)
{
	CString sMsg;
	sMsg.Format("[Method: %s] [Error Msg: %s] [Code: %d]", sFuncName, sErrorMsg, nErrorCode);

	OnErrorLog(sMsg);
}

void CVaxServerExCOM::OnStatusLog(LPCTSTR sMsg)
{

}

void CVaxServerExCOM::OnErrorLog(LPCTSTR sMsg)
{

}

void CVaxServerExCOM::OnInitialize()
{

}