﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using VaxTeleConfigSIP;

namespace ServerSIP
{
    public class cVaxServerSIP : cVaxServerExCOM
    {
        public ErrorLogForm m_objErrorLogDlg = null;
        public StatusLogForm m_objStatusLogDlg = null;

        const string HOLD_MUSIC_FILE = "Hold.wav";
        const string DIAL_TONE_MUSIC_FILE = "DialTone.wav";

        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////////////////////////////

        public cVaxServerSIP()
        {
        }

        ~cVaxServerSIP()
        { 
        
        }

        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////////////////////////////

        public bool Initialize(string sDomainRealm, string sSIPListenIP, int nSIPListenPort)
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();

            if (!objStoreCOMM.Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sSIPListenIP, -1))
                return false;

            if (!base.Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sSIPListenIP, -1))
                return false;

            base.SetListenPortRangeRTP(20000, 30000);
            return true;
        }
        
        public bool GetInitialize(ref  string sSIPListenIP, ref  int nSIPListenPort)
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();

            string sDomainRealm = "", sRTPListenIP = "";
            int nRTPListenPort = -1;

            if (!objStoreCOMM.GetInitialize(ref sDomainRealm, ref sSIPListenIP, ref nSIPListenPort, ref sRTPListenIP, ref nRTPListenPort))
                return false;

            return true;
        }
        
        public new bool LoadMusicHold(string sFileName)
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();
            objStoreCOMM.SetMusicHold(sFileName);

            return base.LoadMusicHold(sFileName);
        }

        public string GetMusicHold()
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();
            string sFileName = "";

            if (!objStoreCOMM.GetMusicHold(ref sFileName))
            {
                sFileName = HOLD_MUSIC_FILE;
            }
            
            return sFileName;
        }
        
        public new bool LoadMusicDialTone(string sFileName)
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();
            objStoreCOMM.SetMusicDialTone(sFileName);

            return base.LoadMusicDialTone(sFileName);
        }

        public string GetMusicDialTone()
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();
            string sFileName = "";

            if (!objStoreCOMM.GetMusicDialTone(ref sFileName))
            {
                sFileName = DIAL_TONE_MUSIC_FILE;
            }

            return sFileName;
        }

        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        
	    public new bool AddUser(string sLogin, string sPassword, string sCodecList, bool bBlocked, string sUserPrefix, string sDialPrefix, int nToPeerType, string sToPeerName)
        {
            if (!base.IsInitialized())
                return false;

            if (sLogin.Length == 0)
                return false;

            RemoveUser(sLogin);

            cStoreUser objStoreUser = new cStoreUser();
            objStoreUser.AddUser(sLogin, sPassword, sCodecList, bBlocked);

            if (sUserPrefix.Length != 0 || sDialPrefix.Length != 0)
            {
                objStoreUser.AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
                base.AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
            }
            
            return base.AddUser(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
        }

	    public new void RemoveUser(string sLogin)
        {
            if (!base.IsInitialized())
                return;

            if (sLogin.Length == 0)
                return;

            cStoreUser objStoreUser = new cStoreUser();
            objStoreUser.RemoveUser(sLogin);
                        
            base.RemoveUser(sLogin);
            base.RemoveUserRoute(sLogin);
        }

        public new void GetUserAll(ref ArrayList objList)
        {
            if (!base.IsInitialized())
                return;

            List<string> objListUserName = new List<string>();
            
            cStoreUser objStoreUser = new cStoreUser();
            objStoreUser.GetUserNameAll(ref objListUserName);

            objList.AddRange(objListUserName);       
        }

        public new bool GetUserDetails(string sUserName, ref string sPassword, ref string sCodecList, ref bool bBlocked, ref string sUserPrefix, ref string sDialPrefix, ref int nToPeerType, ref string sToPeerName)
        {
            if (!base.IsInitialized())
                return false;

            cStoreUser objStoreUser = new cStoreUser();

            objStoreUser.GetUser(sUserName, ref sPassword, ref sCodecList, ref bBlocked);
            objStoreUser.GetUserRoute(sUserName, ref sUserPrefix, ref sDialPrefix, ref nToPeerType, ref sToPeerName);

            return true;
        }

        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////////////////////////////

        public new bool AddLine(string sLineName, string sDisplayName, string sUserName, string sAuthUser, string sAuthPwd, string sDomainRealm, string sProxySIP, string sCodecList, bool bRegister, int nToPeerType, string sToPeerName, bool bRejected, string sRoomName)
        {
            if (!base.IsInitialized())
                return false;

            this.RemoveLine(sLineName);

            cStoreLine objStoreLine = new cStoreLine();

            objStoreLine.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, "", sCodecList, bRegister);
            objStoreLine.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);

            base.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);
            return base.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bRejected, sRoomName);
        }

	    public new void RemoveLine(string sLineName)
        {
            if (!base.IsInitialized())
                return;

            cStoreLine objStoreLine = new cStoreLine();

            objStoreLine.RemoveLine(sLineName);
            objStoreLine.RemoveLineRoute(sLineName);

            base.RemoveLine(sLineName);
            base.RemoveLineRoute(sLineName);
        }

        public new void GetLineAll(ref ArrayList objList)
        {
            if (!base.IsInitialized())
                return;

            List<string> objListLineName = new List<string>();

            cStoreLine objStoreLine = new cStoreLine();
            objStoreLine.GetLineNameAll(ref objListLineName);

            objList.AddRange(objListLineName);
        }

        public new bool GetLineDetails(string sLineName, ref string sDisplayName, ref string sUserName, ref string sAuthUser, ref string sAuthPwd, ref string sDomainRealm, ref string sProxySIP, ref string sCodecList, ref bool bRegister, ref int nToPeerType, ref string sToPeerName, ref bool bRejected, ref string sRoomName)
        {
            if (!base.IsInitialized())
                return false;

            cStoreLine objStoreLine = new cStoreLine();

            string sOutBountProxySIP = "";
            objStoreLine.GetLine(sLineName, ref sDisplayName, ref sUserName, ref sAuthUser, ref sAuthPwd, ref sDomainRealm, ref sProxySIP, ref sOutBountProxySIP, ref sCodecList, ref bRegister);
            objStoreLine.GetLineRoute(sLineName, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName);

            return true;
        }

        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////////////////////////////

        public bool AddDirectProxySIP(string sProxyName, string sAuthLogin, string sAuthPwd, string sDomainRealm, string sProxyIP, int nProxyPort, string sCodecList, int nToPeerType, string sToPeerName, bool bBlock, bool bAddToConf, string sRoomName)
        {
            if (!base.IsInitialized())
                return false;

            this.RemoveDirectProxySIP(sProxyName);

            cStoreDirectProxy objStoreDirectProxy = new cStoreDirectProxy();

            objStoreDirectProxy.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList);
            objStoreDirectProxy.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bBlock, sRoomName);

            base.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bBlock, sRoomName);
            return base.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList, nToPeerType, sToPeerName, bBlock, sRoomName);
        }

	    public new void RemoveDirectProxySIP(string sProxyName)
        {
            if (!base.IsInitialized())
                return;

            cStoreDirectProxy objStoreDirectProxy = new cStoreDirectProxy();

            objStoreDirectProxy.RemoveDirectProxyRoute(sProxyName);
            objStoreDirectProxy.RemoveDirectProxySIP(sProxyName);

            base.RemoveDirectProxyRoute(sProxyName);
            base.RemoveDirectProxySIP(sProxyName);
        }

        public new void GetDirectProxyAll(ref ArrayList objList)
        {
            if (!base.IsInitialized())
                return;

            List<string> objListProxiesName = new List<string>();

            cStoreDirectProxy objStoreDirectProxy = new cStoreDirectProxy();
            objStoreDirectProxy.GetDirectProxySIPAll(ref objListProxiesName);

            objList.AddRange(objListProxiesName);
        }

        public new bool GetDirectProxyDetails(string sProxyName, ref string sAuthLogin, ref string sAuthPwd, ref string sDomainRealm, ref string sProxyIP, ref int nProxyPort, ref string sCodecList, ref int nToPeerType, ref string sToPeerName, ref bool bRejected, ref string sRoomName)
        {
            if (!base.IsInitialized())
                return false;

            cStoreDirectProxy objStoreDirectProxy = new cStoreDirectProxy();
            objStoreDirectProxy.GetDirectProxySIP(sProxyName, ref sAuthLogin, ref sAuthPwd, ref sDomainRealm, ref sProxyIP, ref nProxyPort, ref sCodecList);
            objStoreDirectProxy.GetDirectProxyRoute(sProxyName, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName);
            
            return true;
        }

        ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
        ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

        public new bool AddRoom(string sRoomName, string sRoomNo)
        {
            if (!base.IsInitialized())
                return false;

            this.RemoveRoom(sRoomName);

            if (!base.AddRoom(sRoomName, sRoomNo))
                return false;

            cStoreRoom objStoreRoom = new cStoreRoom();
            objStoreRoom.AddRoom(sRoomName, sRoomNo);

            return true;
        }

        public new void RemoveRoom(string sRoomName)
        {
            if (!base.IsInitialized())
                return;

            cStoreRoom objStoreRoom = new cStoreRoom();
            objStoreRoom.RemoveRoom(sRoomName);

            base.RemoveRoom(sRoomName);
        }

        public new bool GetRoomDetails(string sRoomName, ref string sRoomNo)
        {
            if (!base.IsInitialized())
                return false;

            cStoreRoom objStoreRoom = new cStoreRoom();
            objStoreRoom.GetRoom(sRoomName, ref sRoomNo);

            return true;
        }
        
        public new bool GetRoomAll(ref ArrayList aRoomList)
        {
            if (!base.IsInitialized())
                return false;

            List<string> objListRoomNameList = new List<string>();

            cStoreRoom objStoreRoom = new cStoreRoom();
            objStoreRoom.GetRoomAll(ref objListRoomNameList);

            aRoomList.AddRange(objListRoomNameList);
            return true;
        }

        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////////////////////////////

        private void LoadUser()
        {
            if(!base.IsInitialized())
                return;

            List<string> objListUsers = new List<string>();

            cStoreUser objStoreUsre = new cStoreUser();
            objStoreUsre.GetUserNameAll(ref objListUsers);

            if(objListUsers.Count == 0)
                return;

            string sPassword = "", sCodecList = "";
            string sUserPrefix = "", sDialPrefix = "", sToPeerName = "";

            bool bBlocked = false;
            int nToPeerType = -1;

            foreach (string sUserName in objListUsers)
            {
               objStoreUsre.GetUser(sUserName, ref sPassword, ref sCodecList, ref bBlocked);
               objStoreUsre.GetUserRoute(sUserName, ref sUserPrefix, ref sDialPrefix, ref nToPeerType, ref sToPeerName);
   
               if(sUserPrefix.Length != 0 || sDialPrefix.Length != 0)
               {
                 base.AddUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
               }

               base.AddUser(sUserName, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
            }
        }

        private void LoadLine()
        {
            if (!base.IsInitialized())
                return;

            List<string> objListLines = new List<string>();

            cStoreLine objStoreLine = new cStoreLine();
            objStoreLine.GetLineNameAll(ref objListLines);

            string sDisplayName = "", sUserName = "", sAuthUser = "", sAuthPwd = "", sDomainRealm = "", sProxySIP = "", sCodecList = "", sOutboundProxySIP = "";
            string sToPeerName = "", sRoomName = "";

            bool bRejected = false, bRegister = false;
            int nToPeerType = -1;

            if (objListLines.Count == 0)
                return;

            foreach (string sLineName in objListLines)
            {
                objStoreLine.GetLine(sLineName, ref sDisplayName, ref sUserName, ref sAuthUser, ref sAuthPwd, ref sDomainRealm, ref sProxySIP, ref sOutboundProxySIP, ref sCodecList, ref bRegister);
                objStoreLine.GetLineRoute(sLineName, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName);

                base.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bRejected, sRoomName);
                base.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);
            }
        }

        private void LoadDirectProxy()
        {
            if (!base.IsInitialized())
                return;

            List<string> objListProxy = new List<string>();

            cStoreDirectProxy objStoreProxy = new cStoreDirectProxy();
            objStoreProxy.GetDirectProxySIPAll(ref objListProxy);

            if (objListProxy.Count == 0)
                return;

            string sAuthLogin = "", sAuthPwd = "", sDomainRealm = "", sProxyIP = "", sCodecList = "", sToPeerName = "", sRoomName = "";
            int nProxyPort = -1, nToPeerType = -1;

            bool bRejected = false;
            
            foreach (string sProxy in objListProxy)
            {
                objStoreProxy.GetDirectProxySIP(sProxy, ref sAuthLogin, ref sAuthPwd, ref sDomainRealm, ref sProxyIP, ref nProxyPort, ref sCodecList);
                objStoreProxy.GetDirectProxyRoute(sProxy, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName);

                this.AddDirectProxySIP(sProxy, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList, nToPeerType, sToPeerName, bRejected, sRoomName);
                this.AddDirectProxyRoute(sProxy, nToPeerType, sToPeerName, bRejected, sRoomName);
            }
        }
        
        private void LoadConfRoom()
        {
            if (!base.IsInitialized())
                return;

            List<string> objListRoom = new List<string>();

            cStoreRoom objStoreRoom = new cStoreRoom();
            string sRoomNo = "";

            objStoreRoom.GetRoomAll(ref objListRoom);

            if (objListRoom.Count == 0)
               return;

            foreach (string sRoomName in objListRoom)
            {
               objStoreRoom.GetRoom(sRoomName, ref sRoomNo);
               this.AddRoom(sRoomName, sRoomNo);
            }
        }

        /////////////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////////////

        private Boolean LoadUserDefault()
        {
            cStoreUser objStoreUser = new cStoreUser();

            if (objStoreUser.IsDataStored())
                return false;

            for (int nCount = 4040; nCount <= 4050; nCount++)
                this.AddUser(nCount.ToString(), nCount.ToString(), "32014", false, "", "", cVaxServerCOM.VAX_PEER_TYPE_USER, "");
            
            return true;
        }

        public override void OnInitialize()
        {
            if (!LoadUserDefault())
            {
                LoadUser();
            }

            LoadLine();
            LoadDirectProxy();
            LoadConfRoom();
        }

        public override void OnStatusLog(string sMsg)
        {
            m_objStatusLogDlg.OnStatusLog(sMsg);
        }
        public override void OnErrorLog(string sMsg)
        {
            m_objErrorLogDlg.OnErrorLog(sMsg);
        }
    }
}
